# Python Tailwind Colors

Use the default color palette from TailwindCSS (https://tailwindcss.com/docs/customizing-colors) in your python code for plotting, image generation, etc..

<br/>

**Installation:**

```bash
poetry add tailwind_colors
# or
pip install tailwind_colors
```

<br/>

**Usage:**

```python
from tailwind_colors import TAILWIND_COLORS

print(TAILWIND_COLORS.FUCHSIA_600)  # prints '#c026d3'
```
